@@ -40,7 +40,7 @@ _vzctl()
 	#echo "COMP_WORDS: $COMP_WORDS"
 	#echo "COMP_CWORD: $COMP_CWORD"
 	#echo "COMP_WORDS[1]: ${COMP_WORDS[1]}"
-	
+
 	COMPREPLY=()
 	cur=${COMP_WORDS[COMP_CWORD]}
 	prev=${COMP_WORDS[COMP_CWORD-1]}
@@ -58,10 +58,10 @@ _vzctl()
 		--dgramrcvbuf --oomguarpages --lockedpages --privvmpages \
 		--shmpages --numfile --numflock --numpty --numsiginfo \
 		--dcachesize --numiptent --physpages --cpuunits --cpulimit \
-		--iptables --netdev_add --netdev_del --veth_add --veth_del \
+		--iptables --netdev_add --netdev_del --netif_add --netif_del \
 		--diskspace --diskinodes --quotatime --quotaugidlimit \
-		--noatime --capability --devnodes --applyconfig --name \
-		--ioprio"
+		--noatime --capability --devnodes --devices --applyconfig \
+		--name --ioprio --setmode --meminfo"
 
 	iptables_names="iptable_filter iptable_mangle ipt_limit
 		ipt_multiport ipt_tos ipt_TOS ipt_REJECT ipt_TCPMSS
@@ -75,8 +75,8 @@ _vzctl()
 		sys_module sys_rawio sys_chroot sys_ptrace sys_pacct
 		sys_admin sys_boot sys_nice sys_resource sys_time
 		sys_tty_config mknod lease setveid ve_admin"
-		
-									  
+
+
 
 	case $COMP_CWORD in
 	1)
@@ -105,21 +105,24 @@ _vzctl()
 			# VEID
 			COMPREPLY=( $( compgen -W "$(_get_ves $prev)" -- $cur ) )
 		else
-	
+
 			# flag or option
 			case $prev in
 			--ostemplate)
 				# get the template path from the vz.conf
 				local vztmpl=`grep ^TEMPLATE /etc/vz/vz.conf | cut -d "=" -f 2`
-				COMPREPLY=( $( compgen -W "$(ls -1 $vztmpl/cache/*.tar.gz | \
+				COMPREPLY=( $( compgen -W "$(ls -1 $vztmpl/cache/*.tar.gz |
 						    sed -e "s#^$vztmpl/cache/##" -e 's#.tar.gz$##')" -- $cur ) )
 
 				;;
 			--onboot|--disabled|--noatime)
 				COMPREPLY=( $( compgen -W "yes no" -- $cur ) )
 				;;
+			--setmode)
+				COMPREPLY=( $( compgen -W "restart ignore" -- $cur ) )
+				;;
 			--config|--applyconfig)
-				local configs=$(ls -1 /etc/vz/conf/*.conf-sample | \
+				local configs=$(ls -1 /etc/vz/conf/*.conf-sample |
 						    cut -d "-" -f 2- | sed -e 's#.conf-sample$##')
 
 				configs=${configs/.conf-sample/}
@@ -134,6 +137,15 @@ _vzctl()
 
 				COMPREPLY=( $( compgen -W "$devs" -- $cur ) )
 				;;
+			--meminfo)
+				local meminfo="none privvmpages:1"
+				COMPREPLY=( $( compgen -W "$meminfo" -- $cur ) )
+				;;
+			--ioprio)
+				# ioprio range: 0 - 7 (default : 4)
+				local ioprio='0 1 2 3 4 5 6 7'
+				COMPREPLY=( $( compgen -W "$ioprio" -- $cur ) )
+				;;
 			--capability)
 				# capname:on|off
 				COMPREPLY=( $( compgen -W "$cap_names" -- $cur ) )
@@ -154,6 +166,11 @@ _vzctl()
 				local devs=''
 				COMPREPLY=( $( compgen -W "$devs" -- $cur ) )
 				;;
+			--devices)
+				# FIXME: b|c:major:minor|all:r|w|rw
+				local devices=''
+				COMPREPLY=( $( compgen -W "$devices" -- $cur ) )
+				;;
 			--ipdel)
 				# Get VEID
 				local ve=${COMP_WORDS[2]}
@@ -166,6 +183,22 @@ _vzctl()
 				local ips="`/usr/sbin/vzlist -H -o ip $LIST_OPT $ve | grep -vi -`"
 				COMPREPLY=( $( compgen -W "$ips all" -- $cur ) )
 				;;
+			--netif_del)
+				local netif
+				if [ -f /proc/vz/veth ]; then
+					local ve=${COMP_WORDS[2]}
+					if [[ ! ${ve} != '^[1-9][0-9]*$' ]] ; then
+						# --verbose or --quiet used
+						ve=${COMP_WORDS[3]}
+					fi
+					# get veth(ernet) device of VE, proc and config
+					local netif_proc="`awk "/${ve}/ { print \\$4 }" /proc/vz/veth`"
+					local netif_conf="`grep ^NETIF /etc/vz/conf/${ve}.conf |
+						sed -e 's/"/\n/g' -e 's/;/\n/g' -e 's/,/\n/g' -e 's/=/ /g' | awk '/^ifname/ {print \$2}'`"
+					netif="$netif_proc $netif_conf"
+				fi
+				COMPREPLY=( $( compgen -W "$netif" -- $cur ) )
+				;;
 			--private|--root)
 				# FIXME
 				# Dir autocompletion works bad since there is
@@ -182,7 +215,7 @@ _vzctl()
 						# --verbose or --quiet used
 						cmd=${COMP_WORDS[2]}
 					fi
-		
+
 					case "$cmd" in
 					create)
 						COMPREPLY=( $( compgen -W "$vzctl_create_opts" -- $cur ) )
